@@ -1,6 +1,7 @@
 import typing
 
-from xpresso.dependencies.models import Dependant
+from di import Dependant
+
 from xpresso.security._base import SecurityBase as SecurityModel
 from xpresso.security._dependants import Security as SecurityDependant
 
@@ -9,13 +10,14 @@ def Security(
     model: typing.Union[SecurityModel, typing.Type[SecurityModel]],
     *,
     scopes: typing.Optional[typing.Sequence[str]] = None,
-) -> Dependant:
+) -> Dependant[typing.Any]:
     if isinstance(model, SecurityModel):
         call = type(model).__call__
     else:
         call = model.__call__
-    return Dependant(
+    return Dependant[typing.Any](
         call,
+        scope="connection",
         overrides={
             "self": SecurityDependant(
                 dependency=model,
